Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2888)

Unified Diff: chrome/browser/spellchecker/misspelling.h

Issue 1545223002: Switch to standard integer types in chrome/browser/, part 4 of 4. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/spellchecker/feedback_unittest.cc ('k') | chrome/browser/spellchecker/misspelling.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/spellchecker/misspelling.h
diff --git a/chrome/browser/spellchecker/misspelling.h b/chrome/browser/spellchecker/misspelling.h
index d7e4c28067f7eccd710c9d68a6cb50fe78ea735e..44bd78a67ff07b672bfc78e7782a85cf7e034c7d 100644
--- a/chrome/browser/spellchecker/misspelling.h
+++ b/chrome/browser/spellchecker/misspelling.h
@@ -4,7 +4,7 @@
//
// An object to store user feedback to a single spellcheck suggestion.
//
// Stores the spellcheck suggestion, its uint32 hash identifier, and user's
// feedback. The feedback is indirect, in the sense that we record user's
// |action| instead of asking them how they feel about a spellcheck suggestion.
// The object can serialize itself.
@@ -12,6 +12,9 @@
#ifndef CHROME_BROWSER_SPELLCHECKER_MISSPELLING_H_
#define CHROME_BROWSER_SPELLCHECKER_MISSPELLING_H_
+#include <stddef.h>
+#include <stdint.h>
+
#include <vector>
#include "base/time/time.h"
@@ -34,7 +37,7 @@ struct Misspelling {
size_t location,
size_t length,
const std::vector<base::string16>& suggestions,
- uint32 hash);
+ uint32_t hash);
~Misspelling();
// A several-word text snippet that immediately surrounds the misspelling.
@@ -51,7 +54,7 @@ struct Misspelling {
std::vector<base::string16> suggestions;
// The hash that identifies the misspelling.
- uint32 hash;
+ uint32_t hash;
// User action.
SpellcheckAction action;
« no previous file with comments | « chrome/browser/spellchecker/feedback_unittest.cc ('k') | chrome/browser/spellchecker/misspelling.cc » ('j') | no next file with comments »
@@ -4,7 +4,7 @@
// An object to store user feedback to a single spellcheck suggestion.
//
-// Stores the spellcheck suggestion, its uint32 hash identifier, and user's
+// Stores the spellcheck suggestion, its uint32_t hash identifier, and user's
// feedback. The feedback is indirect, in the sense that we record user's
// |action| instead of asking them how they feel about a spellcheck suggestion.

Powered by Google App Engine
This is Rietveld 408576698